#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SPLAT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SPLAT_HPP_INCLUDED

#include <boost/simd/memory/include/functions/splat.hpp>

#endif
